@@ -5,14 +5,13 @@
 from __future__ import annotations
 
 from queue import Queue
-from typing import Optional
+from typing import Optional, Union
 
 from revsymg.algorithms.connected_components.cnnted_comp_id import (
     RevSymCCId,
     _RevSymCCIdFactory,
 )
 from revsymg.exceptions import NotNoneCCompId
-from revsymg.graphs.graphs_lib import GraphsCnntedCompT, GraphsT
 from revsymg.graphs.merged_strands_graph import MergedStrandsRevSymGraph
 from revsymg.graphs.revsym_graph import RevSymGraph
 from revsymg.graphs.split_strands_graph import SplitStrandsGraph
@@ -21,6 +20,21 @@ from revsymg.graphs.split_strands_vertices import SplitStrandsVertices
 from revsymg.lib.index_lib import IND, OR, IndOrT
 
 
+# ============================================================================ #
+#                                     TYPES                                    #
+# ============================================================================ #
+GraphsT = Union[
+    RevSymGraph,
+    # SubRevSymGraph,
+    MergedStrandsRevSymGraph,
+    SplitStrandsGraph,
+]
+GraphsCnntedCompT = Union[
+    SplitStrandsGraph,
+    MergedStrandsRevSymGraph,
+]
+
+
 # ============================================================================ #
 #                                   FUNCTIONS                                  #
 # ============================================================================ #
