@@ -45,11 +45,17 @@ class Vertices():
 
     def __init__(self, _adjs: _AdjsT):
         """The Initializer."""
-        # Adjancy tables ---
+        #
+        # Adjacency tables
+        #
         self._adjs: _AdjsT = _adjs
+        #
         # Attributes for vertices
+        #
         self._attributes: AttributesContainer = AttributesContainer()
+        #
         # Number of forward vertices
+        #
         self._card_vf: int = 0
 
     # -*- Attributes -*-
@@ -191,7 +197,7 @@ class Vertices():
         Returns
         -------
         IndexT
-            Last vertex's index (unoriented)
+            Last vertex's index (non-oriented)
         """
         self._adjs[PRED_IND].extend([[] for _ in range(number)])
         self._adjs[SUCC_IND].extend([[] for _ in range(number)])
